/********************************************************************
* $ Source $
*
* Workfile: drv_osc.c
* Author: MICROCHIPS Korea CAE Team
* Date  : 2016/08
*
* [Test Environment]
* - Development Environment : MPLAB X IDE v3.35
* - Compiler                : XC8 v1.38
* - Hardware                : PICDEM 2 Plus Demo Board
* - Target Processor        : PIC16F1937
*
* Description :
*  Oscillator driver.
*
* Revision History:
********************************************************************/


/********************************************************************
* Header Files
********************************************************************/

#include <xc.h>
#include "pic16f1937.h"
#include "drv_osc.h"



/********************************************************************
* Function		: DRV_OSC_Init
* Description	: Oscillator Initialization
* Argument		: 
* Return		: None
********************************************************************/

void DRV_OSC_Init(void)
{
	/*---------------------------------------------------------------*/
	/* OSCCON : Oscillator Control Register                          */
	/* Description :                                                 */
	/* bit [7]   SPLLEN : Software PLL Enable bit                    */
	/* bit [6-3] IRCF   : Internal Oscillator Frequence Select bits  */
	/* bit [2]          : Not Used                                   */
	/* bit [1-0] SCS    : System Clock Select bits                   */
	/* [Property]                                                    */
	/*     Mandatory register to configure clock generation          */
	/*---------------------------------------------------------------*/
    /* This is same to OSCCON = (0 << 7) | (0xF << 3) | (0x02) */
	OSCCONbits.SPLLEN = 0;		// Disable SPLLEN
	OSCCONbits.IRCF3 = 1;		//
	OSCCONbits.IRCF2 = 1;		//
	OSCCONbits.IRCF1 = 1;		//
	OSCCONbits.IRCF0 = 1;		// IRCF[3..0] = 0xF (16MHz High Frequency)
	OSCCONbits.SCS1 = 1;		//
	OSCCONbits.SCS0 = 0;		// SCS[1..0] = 2 (Internal oscillator block used)

	/*---------------------------------------------------------------*/
	/* OSCTUNE : Oscillator Tuning Register                          */
	/* Description :                                                 */
	/* bit [7-6]        : Not Used                                   */
	/* bit [5-0] TUN    : Frequency Tuning bits                      */
	/* [Property]                                                    */
	/*     Mandatory register to calibrate frequency                 */
	/*---------------------------------------------------------------*/
    OSCTUNE = 0x00;		// = Oscillator module is running at the factory-calibrated frequency
}

/* End of File */
