/********************************************************************
* $ Source $
*
* Workfile: drv_wdt.c
* Author: MICROCHIPS Korea CAE Team
* Date  : 2016/08
*
* [Test Environment]
* - Development Environment : MPLAB X IDE v3.35
* - Compiler                : XC8 v1.38
* - Hardware                : PICDEM 2 Plus Demo Board
* - Target Processor        : PIC16F1937
*
* Description :
*  Watchdog driver.
*
* Revision History:
********************************************************************/


/********************************************************************
*	Header Files
********************************************************************/

#include <xc.h>
#include "pic16f1937.h"
#include "drv_wdt.h"



/********************************************************************
* Function		: DRV_WDT_Init
* Description	: Watchdog Initialization
* Argument		: flag         - Watchdog Enabled/Disabled
*                 period_index - Watchdog period selection
* Return		: None
********************************************************************/

void DRV_WDT_Init(uint8_t flag, uint8_t period_index)
{
	/*-------------------------------------------------------------------*/
	/* WDTCON : Watchdog Timer Control Register                          */
	/* Description :                                                     */
	/* bit [7-6]        : Not Used                                       */
	/* bit [5-1] WDTPS  : Watchdog Timer Period Select bits              */
	/* bit [0] SWDTEN   : Software Enable/Disable for Watchdog Timer bit */
	/* [Property]                                                        */
	/*     Mandatory register to initialize MCU                          */
	/*-------------------------------------------------------------------*/
    /* This is same to WDTCON = (period_index << 1) | (flag) */
	if(flag == 1)
	{
		WDTCONbits.WDTPS = period_index;
	}

	WDTCONbits.SWDTEN = flag;
}

/* End of File */
