/********************************************************************
* $ Source $
*
* Workfile: interrupt_isr.c
* Author: MICROCHIPS Korea CAE Team
* Date  : 2016/08
*
* [Test Environment]
* - Development Environment : MPLAB X IDE v3.35
* - Compiler                : XC8 v1.38
* - Hardware                : PICDEM 2 Plus Demo Board
* - Target Processor        : PIC16F1937
*
* Description :
*  Interrupt manager and TimerX interrupt service routines.
*
* Revision History:
********************************************************************/


/********************************************************************
*	Header Files
********************************************************************/

#include <xc.h>
#include "typedef.h"


/********************************************************************
*	Global/Static Function
********************************************************************/

static void TMR0_ISR(void);
static void TMR1_ISR(void);
static void TMR2_ISR(void);
static void TMR4_ISR(void);


/********************************************************************
*	Global/Static Variables
********************************************************************/

static volatile uint8_t s_timer2_inc = 0;
static volatile uint16_t s_timer4_inc = 0;



/********************************************************************
* Function		: PIC16F1937_INTERRUPT_Manager
* Description	: Interrupt service routine of PIC16F1937
* Argument		: None
* Return		: None
********************************************************************/

void interrupt PIC16F1937_INTERRUPT_Manager(void)
{
	/* Timer0 interrupt handler*/
    if(INTCONbits.TMR0IE == 1 && INTCONbits.TMR0IF == 1)
    {
        TMR0_ISR();
    }

	/* Timer1 interrupt handler*/
    if(PIE1bits.TMR1IE == 1 && PIR1bits.TMR1IF == 1)
    {
        TMR1_ISR();
    }

	/* Timer2 interrupt handler*/
    if(PIE1bits.TMR2IE == 1 && PIR1bits.TMR2IF == 1)
    {
        TMR2_ISR();
    }

	/* Timer4 interrupt handler*/
    if(PIE3bits.TMR4IE == 1 && PIR3bits.TMR4IF == 1)
    {
        TMR4_ISR();
    }

	/* ISR to implement properly... */
#if 0	// This is example code...
	if(PIE1bits.RCIE == 1 && PIR1bits.RCIF == 1)
    {
		UART_Recv_ISR();
    }

	if(PIE1bits.CCP1IE == 1 && PIR1bits.CCP1IF == 1)
    {
		//Capture1_ISR();
		Compare1_ISR();
    }

	if(PIE2bits.C1IE == 1 && PIR2bits.C1IF == 1)
    {
		Comparator_ISR();
    }

    if(PIE1bits.SSPIE == 1 && PIR1bits.SSPIF == 1)
    {
		SPI_ISR();
    }

	if(PIE2bits.BCLIE == 1 && PIR2bits.BCLIF == 1)
    {
        //I2C_BusCollisionISR();
    }
    else if(PIE1bits.TXIE == 1 && PIR1bits.TXIF == 1)
    {
        //EUSART_Transmit_ISR();
    }
    else
    {
		//PORTBbits.RB2 = 0;
        //Unhandled Interrupt
    }
#endif
}



/********************************************************************
* Function		: TMR0_ISR
* Description	: Timer0 Interrupt Service Routine
* Argument		: None
* Return		: None
********************************************************************/

static void TMR0_ISR(void)
{
	/* Clear the TMR0 interrupt flag TMR0IF. */
	INTCONbits.TMR0IF = 0;

	/* Toggle RB0.*/
	PORTBbits.RB0 = ~PORTBbits.RB0;
}  



/********************************************************************
* Function		: TMR1_ISR
* Description	: Timer1 Interrupt Service Routine
* Argument		: None
* Return		: None
********************************************************************/

static void TMR1_ISR(void)
{
	/* Clear the TMR1 interrupt flag TMR1IF. */
	PIR1bits.TMR1IF = 0;

	/* Set start value TMR1H & TMR1L */
	TMR1H = 0x80;
	TMR1L = 0x0;

	/* Toggle RB0.*/
	PORTBbits.RB1 = ~PORTBbits.RB1;
}



/********************************************************************
* Function		: TMR2_ISR
* Description	: Timer2 Interrupt Service Routine
* Argument		: None
* Return		: None
********************************************************************/

static void TMR2_ISR(void)
{
	/* Clear the TMR2 interrupt flag TMR2IF. */
	PIR1bits.TMR2IF = 0;
	s_timer2_inc++;

	/* 61 = (((16000000/4) / 16) / 16) / 256 */
	if(s_timer2_inc == 61)
	{
		s_timer2_inc = 0;
		PORTBbits.RB2 = ~PORTBbits.RB2;
	}
}



/********************************************************************
* Function		: TMR4_ISR
* Description	: Timer4 Interrupt Service Routine
* Argument		: None
* Return		: None
********************************************************************/

static void TMR4_ISR(void)
{
	/* Clear the TMR4 interrupt flag TMR4IF. */
	PIR3bits.TMR4IF = 0;
	s_timer4_inc++;

	/* 1953 = (((16000000/4) / 16) / 64) / 2 */
	if(s_timer4_inc == 1953)
	{
		s_timer4_inc = 0;
		PORTBbits.RB3 = ~PORTBbits.RB3;
	}
}

/* End of File */
